# Generated by Django 3.2.5 on 2021-07-19 19:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('python_telegram_bot_django_persistence', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='conversationdata',
            name='state',
            field=models.JSONField(blank=True, null=True),
        ),
    ]
