from django.apps import AppConfig


class PythonTelegramBotDjangoPersistenceConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "python_telegram_bot_django_persistence"
